@@ -42,38 +42,86 @@ sub get {
 
     my %data = (key => $key);
     my $response = <$socket>;
-    if ($response =~ m/VALUE \S+ (\d+) (\d+)/) {
+    if ($response =~ m/^VALUE \S+ (\d+) (\d+)/) {
         $data{flags}  = $1;
         $data{length} = $2;
         read $socket, $response, $data{length};
         $data{value} = $response;
 
-        while ($response !~ m/^END/) { $response = <$socket>; }
+        while ($response !~ m/^END/) { $response = $self->_readline; }
+    } elsif ($response =~ m/^END/) {
+        # not found
     } else {
-        warn "KEY $key not found in $response";
+        warn "Unknown response for KEY '$key'. '$response'";
     }
 
     return \%data;
 }
 
+sub set {
+    my $self   = shift;
+    my $key    = shift;
+    my $value  = shift;
+    my %option = @_;
+    my $flags  = $option{flags}  || 0;
+    my $expire = $option{expire} || 0;
+    my $bytes  = sub {
+        use bytes;
+        return length $value;
+    }->();
+
+    my $socket = $self->{socket};
+    print $socket "set $key $flags $expire $bytes\r\n";
+    print $socket "$value\r\n";
+    my $response = $self->_readline;
+    if ($response !~ m/^STORED/) {
+        warn "Failed to set '$key' with '$value'";
+        return;
+    }
+    return 1;
+}
+
 sub query {
     my $self  = shift;
     my $query = shift;
+    my $response = eval {
+        return $self->_query($query);
+    };
+    if ($@) {
+        confess "Failed to query! query: $query ERROR: " . $@;
+    }
+    return $response;
+}
+
+sub _query {
+    my $self  = shift;
+    my $query = shift;
 
     my $socket = $self->{socket};
     print $socket "$query\r\n";
 
     my @response;
-    while (<$socket>) {
-        last if m/^(OK|END)/;
-        confess $_ if m/^(CLIENT|SERVER_)?ERROR/;
-        $_ =~ s/[\r\n]+$//;
-        push @response, $_;
+    while (1) {
+        my $line = $self->_readline;
+        $line =~ s/[\r\n]+$//;
+        last if ($line =~ m/^(OK|END)/);
+        die $line if ($line =~ m/^(CLIENT|SERVER_)?ERROR/);
+        push @response, $line;
     }
 
     return \@response;
 }
 
+sub _readline {
+    my $self   = shift;
+    my $socket = $self->{socket};
+    local $SIG{ALRM} = sub { die 'Timed out to Read Socket.' };
+    alarm 3;
+    my $line = <$socket>;
+    alarm 0;
+    return $line;
+}
+
 sub DESTROY {
     my $self = shift;
     if ($self->{socket}) { $self->{socket}->close; }
