@@ -16,7 +16,7 @@ use App::Memcached::CLI::DataSource;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.4.0';
+use version; our $VERSION = 'v0.5.0';
 
 my $PROGRAM = basename $0;
 
@@ -30,6 +30,7 @@ my %COMMAND2ALIASES = (
     detaildump => [qw(\dd)],
     detail     => [],
     get        => [],
+    set        => [],
 );
 my %COMMAND_OF;
 while (my ($cmd, $aliases) = each %COMMAND2ALIASES) {
@@ -221,6 +222,17 @@ EODESC
             description => <<'EODESC',
 Usage:
     > get <KEY>
+EODESC
+        },
+        +{
+            command => 'set',
+            summary => 'Set data with KEY, VALUE',
+            description => <<'EODESC',
+Usage:
+    > set <KEY> <VALUE> [<EXPIRE> [<FLAGS>]]
+    > set mykey1 MyValue1
+    > set mykey2 MyValue2 0     # Never expires. Default
+    > set mykey3 MyValue3 120 1
 EODESC
         },
     );
@@ -270,10 +282,37 @@ sub _sorted_aliases_of {
 sub get {
     my $self = shift;
     my $key  = shift;
+    unless ($key) {
+        print "No KEY specified.\n";
+        return;
+    }
     my $item = App::Memcached::CLI::Item->find_by_get($key, $self->{ds});
-    return unless $item;
+    unless ($item) {
+        print "Not found - $key\n";
+    } else {
+        print $item->output;
+    }
+    return 1;
+}
 
-    print $item->output;
+sub set {
+    my $self = shift;
+    my ($key, $value, $expire, $flags) = @_;
+    unless ($key and $value) {
+        print "KEY or VALUE not specified.\n";
+        return;
+    }
+    my $item = App::Memcached::CLI::Item->new(
+        key    => $key,
+        value  => $value,
+        expire => $expire,
+        flags  => $flags,
+    );
+    unless ($item->save($self->{ds})) {
+        warn "Failed to store item. KEY $key, VALUE $value";
+        return;
+    }
+    print "OK\n";
     return 1;
 }
 
@@ -376,7 +415,7 @@ sub detaildump {
 
 sub detail {
     my $self = shift;
-    my $mode = shift || 'on';
+    my $mode = shift || q{};
     unless (first { $_ eq $mode } qw/on off/) {
         print "Mode must be 'on' or 'off'!\n";
         return;
